Root

Struct Root 

pub struct Root {
    pub uri: String,
    pub name: Option<String>,
    pub meta: Option<HashMap<String, Value>>,
}
๐Ÿ‘ŽDeprecated since 0.4.0:

Deprecated per SEP-2577 (2026-07-28). Replacement: pass directories or files via tool parameters, resource URIs, or server configuration. Earliest removal: first release on/after 2027-07-28.

Root directory entry.

Deprecated per SEP-2577 โ€” see module-level docs.

Fields

uri: String
๐Ÿ‘ŽDeprecated since 0.4.0:

Deprecated per SEP-2577 (2026-07-28). Replacement: pass directories or files via tool parameters, resource URIs, or server configuration. Earliest removal: first release on/after 2027-07-28.

URI of the root (must start with โ€œfile://โ€ currently)

name: Option<String>
๐Ÿ‘ŽDeprecated since 0.4.0:

Deprecated per SEP-2577 (2026-07-28). Replacement: pass directories or files via tool parameters, resource URIs, or server configuration. Earliest removal: first release on/after 2027-07-28.

Optional human-readable name

meta: Option<HashMap<String, Value>>
๐Ÿ‘ŽDeprecated since 0.4.0:

Deprecated per SEP-2577 (2026-07-28). Replacement: pass directories or files via tool parameters, resource URIs, or server configuration. Earliest removal: first release on/after 2027-07-28.

Optional metadata

Implementations

Source

impl Root

pub fn new(uri: impl Into<String>) -> Root

pub fn with_name(self, name: impl Into<String>) -> Root

pub fn with_meta(self, meta: HashMap<String, Value>) -> Root

pub fn validate(&self) -> Result<(), String>

Validate that the URI follows MCP requirements